#!/bin/bash
#
# EeePC Actions
# Andrew Wyatt
# Generic script to take actions on keypress
#

. /etc/default/eeepc-acpi

function eeepc_notify {
/usr/bin/notify-send -i $2 -t 1500 "EeePC $EEEPC_MODEL" "$1"
}

###  Borrowed this from elmurato's ACPI scripts (Thanks!)
if [ -S /tmp/.X11-unix/X0 ]; then
        export DISPLAY=:0
        user=$(who | sed -n '/ (:0[\.0]*)$\| :0 /{s/ .*//p;q}')
        home=$(getent passwd $user | cut -d: -f6)
        XAUTHORITY=$home/.Xauthority
        [ -f $XAUTHORITY ] && export XAUTHORITY
fi

SELECTION=$3
if [ "$KEY_SHOW" = "1" ]; then
  eeepc_notify "You pressed: \"$SELECTION\"" keyboard
fi
case $SELECTION in
  $POWER_AC)
     $EEEPC_PATH/eeepc-cpu-control.sh $MODE_AC &
  ;;
  $POWER_BAT)
     $EEEPC_PATH/eeepc-cpu-control.sh $MODE_BAT &
  ;;
  $KEY_RESOLUTION)
     $EEEPC_PATH/eeepc-lvds-resolution-toggle.sh &
  ;;
  $KEY_ROTATE)
     $EEEPC_PATH/eeepc-rotate-lvds.sh &
  ;;
  $KEY_FSB)
     $EEEPC_PATH/eeepc-cpu-control.sh &
  ;;
  $KEY_VOLU)
     if [ "$VOL_DEV" = "AUTO" ]; then
       VOL_DEVS=($(amixer -c 0 controls | awk -F "," ' $_ ~ /Playback Volume/ \
	{split($3,a,"=");print a[2]}' | sed -s -e "s#\sPlayback\sVolume'##" -e "s#^'##"))

       for dev in ${VOL_DEVS[*]}; do
         amixer -q -c 0 set $dev $VOL_ADJ+ >/dev/null 2>&1
       done
     else
       amixer -q -c 0 cset $VOL_DEV $VOL_ADJ+ &
     fi
  ;;
  $KEY_VOLD)
     if [ "$VOL_DEV" = "AUTO" ]; then
       VOL_DEVS=($(amixer -c 0 controls | awk -F "," ' $_ ~ /Playback Volume/ \
	{split($3,a,"=");print a[2]}' | sed -s -e "s#\sPlayback\sVolume'##" -e "s#^'##"))

       for dev in ${VOL_DEVS[*]}; do
         amixer -q -c 0 set $dev $VOL_ADJ- >/dev/null 2>&1
       done
     else
       amixer -q -c 0 set $VOL_DEV $VOL_ADJ- &
     fi
  ;;
  $KEY_MUTE)
     MUTE_DEVS=($(amixer -c 0 controls | grep "Playback Switch" | awk -F "," '{printf $1" "}'))
     MUTE_STATE=$(amixer -c 0 cget ${MUTE_DEVS[0]},iface=MIXER | awk '$_ ~ /:/ {split($2,a,"="); print a[2]}')
     if [[ "$MUTE_STATE" =~ "on,on" ]]; then
       for dev in ${MUTE_DEVS[*]}; do
         amixer -q -c 0 cset $dev,iface=MIXER 0 >/dev/null 2>&1
       done
     else
       for dev in ${MUTE_DEVS[*]}; do
         amixer -q -c 0 cset $dev,iface=MIXER 1 >/dev/null 2>&1
       done
     fi
  ;;
  $KEY_VGAOFF)
     $EEEPC_PATH/eeepc-lvds-toggle.sh &
  ;;
  $KEY_VGAOUTA)
     $EEEPC_PATH/eeepc-vga-toggle.sh
  ;;
  $KEY_VGAOUTB)
     $EEEPC_PATH/eeepc-vga-toggle.sh
  ;;
  $KEY_VGAOUTC)
     $EEEPC_PATH/eeepc-vga-toggle.sh
  ;;
  $KEY_PERFMON)
     eeepc_notify "System Monitor" gnome-monitor
     su $user -c /usr/bin/gnome-system-monitor &
  ;;
  $KEY_TOUCHPAD)
     $EEEPC_PATH/eeepc-touchpad-toggle.sh &
  ;;
  $KEY_WIFI)
     $EEEPC_PATH/eeepc-wifi-toggle.sh &
  ;;
  $KEY_BT)
     $EEEPC_PATH/eeepc-bluetooth-toggle.sh &
  ;;
  $KEY_CAM)
     $EEEPC_PATH/eeepc-camera-toggle.sh &
  ;;
  $KEY_CUSTOMA)
    eeepc_notify "Launching $KEY_CUSTOMA_NAME" "$KEY_CUSTOMA_ICON"
    su $user -c $KEY_CUSTOMA_COMMAND $KEY_CUSTOMA_ICON &
  ;;
  $KEY_CUSTOMB)
    eeepc_notify "Launching $KEY_CUSTOMB_NAME" "$KEY_CUSTOMB_ICON"
    su $user -c $KEY_CUSTOMB_COMMAND $KEY_CUSTOMA_ICON &
  ;;
esac
