#!/bin/bash
#
# EeePC Bluetooth Adapter toggle
# Andrew Wyatt
# Tool to toggle Bluetooth device on / off

. /etc/default/eeepc-acpi

function eeepc_notify {
/usr/bin/notify-send -i bluetooth -t 1500 "EeePC $EEEPC_MODEL" "$1"
}

if [ -e "/sys/devices/platform/eeepc/bt" ]; then
  BLUETOOTH_DEVICE="/sys/devices/platform/eeepc/bt"
  BLUETOOTH_RADIO=$(cat $BLUETOOTH_DEVICE)
fi

if [ ! -d "$EEEPC_VAR" ]; then
  mkdir $EEEPC_VAR 2>/dev/null
fi

if [ -e "$EEEPC_VAR/bt_saved" ]; then
  BLUETOOTH_SAVED=$(cat $EEEPC_VAR/bt_saved)
else
  BLUETOOTH_SAVED=1
fi

function bt_toggle {
  if [ "$BLUETOOTH_RADIO" = "-1" ]; then
    eeepc_notify "Bluetooth module not installed"
    exit 1
  elif [ "$BLUETOOTH_RADIO" = "0" ]; then
    eeepc_notify "Bluetooth Enabled"
    /sbin/modprobe bluetooth
    echo 1 > $EEEPC_VAR/bt_saved
    echo 1 > $BLUETOOTH_DEVICE
  elif [ "$BLUETOOTH_RADIO" = "1" ]; then
    eeepc_notify "Bluetooth Disabled"
    echo 0 > $EEEPC_VAR/bt_saved
    echo 0 > $BLUETOOTH_DEVICE
    /sbin/modprobe -r bluetooth 2>/dev/null
  fi
}

function bt_restore {
  if [ "$BLUETOOTH_SAVED" = "1" ]; then
    eeepc_notify "Bluetooth Enabled"
    /sbin/modprobe bluetooth
    echo 1 > $BLUETOOTH_DEVICE
  elif [ "$BLUETOOTH_SAVED" = "0" ]; then
    eeepc_notify "Bluetooth Disabled"
    echo 0 > $BLUETOOTH_DEVICE
    /sbin/modprobe -r bluetooth 2>/dev/null
  fi
}

case $1 in
  restore)
    bt_restore
  ;;
  *)
    bt_toggle
  ;;
esac
