#!/bin/bash
#
# EeePC Touchpad toggle
# Andrew Wyatt
# Tool to enable / disable touchpad

. /etc/default/eeepc-acpi

function eeepc_notify {
/usr/bin/notify-send -i input-tablet -t 1500 "EeePC $EEEPC_MODEL" "$1"
}

if [ ! -d "$EEEPC_VAR" ]; then
  mkdir $EEEPC_VAR
fi

if [ -e "$EEEPC_VAR/touchpad_saved" ]; then
  TPSAVED=$(cat $EEEPC_VAR/touchpad_saved)
fi

function touchpad_toggle {
  TOUCHPAD=`synclient -l | grep TouchpadOff | awk '{print $3}'`
  if [ "$TOUCHPAD" = "0" ]; then
    echo 1 > $EEEPC_VAR/touchpad_saved
    ((synclient TouchpadOff=1 && eeepc_notify "Touchpad Disabled") || eeepc_notify "Unable to disable touchpad; Ensure xorg.conf is properly configured.")
  else
    echo 0 > $EEEPC_VAR/touchpad_saved
    ((synclient TouchpadOff=0 && eeepc_notify "Touchpad Enabled") || eeepc_notify "Unable to enable touchpad; Ensure xorg.conf is properly configured.")
  fi
}

function touchpad_restore {
  if [ "$TPSAVED" = "1" ]; then
    ((synclient TouchpadOff=1 && eeepc_notify "Touchpad Disabled") || eeepc_notify "Unable to disable touchpad; Ensure xorg.conf is properly configured.")
  else
    ((synclient TouchpadOff=0 && eeepc_notify "Touchpad Enabled") || eeepc_notify "Unable to enable touchpad; Ensure xorg.conf is properly configured.")
  fi
}

case $1 in
  restore)
    touchpad_restore
  ;;
  *)
    touchpad_toggle
  ;;
esac
